import requests
import re


def url_check(url):
    pattern = "^https?:\\/\\/(?:www\\.)?[-a-zA-Z0-9@:%._\\+~#=]{1,256}\\.[a-zA-Z0-9()]{1,6}\\b(?:[-a-zA-Z0-9()@:%_\\+.~#?&\\/=]*)$"
    return re.match(pattern, url) is not None


def shorten_url(url):
    # checking if the url is valid
    is_valid_url = url_check(url)

    # adding https:// to the start of the string if url is not valid
    url = f"https://{url}" if not is_valid_url else url

    # checking if the url is valid again
    is_valid_url = url_check(url)

    if not is_valid_url:
        return "Not a valid url."

    data = f"url={url}"

    headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }

    response = requests.post("https://s.lain.la", headers=headers, data=data)
    return response.text



from setuptools import setup, find_packages

VERSION = "1.7"
DESCRIPTION = "URL Shortener using s.lain.la API."
with open("README.md", "r") as file:
    LONG_DESCRIPTION = file.read()
AUTHOR = "NecRaul"

setup(
    name="lain_shorten",
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    packages=find_packages(),
    install_requires=["requests", "pyperclip"],
    keywords=["python", "link shortener", "shortener", "lain", "lain.la", "s.lain.la"],
    url="https://github.com/NecRaul/lain.la-link-shortener",
    project_urls={
        "Documentation": "https://github.com/NecRaul/lain.la-link-shortener#readme",
        "Source": "https://github.com/NecRaul/lain.la-link-shortener",
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Internet :: WWW/HTTP",
    ],
    py_modules=["shorten"],
    entry_points={
        "console_scripts": [
            "lain-shorten = lain_shorten.__init__:main",
        ],
    },
)
